@@ -1,7 +1,7 @@
-from dataclasses import dataclass
 from enum import Enum
-from typing import Union
 from typing import List
+from dataclasses import dataclass
+from typing import Union
 
 
 class ActivationsEnum(Enum):
@@ -203,6 +203,7 @@ class NodeType(Enum):
     Dataset = "Dataset"
     RepresentationBlock = "RepresentationBlock"
     GroundTruth = "GroundTruth"
+    CustomLayer = "CustomLayer"
     CustomLoss = "CustomLoss"
     Visualizer = "Visualizer"
     Lambda = "Lambda"
@@ -1683,6 +1684,11 @@ class GroundTruth:
     type: NodeType
 
 
+@dataclass
+class CustomLayer:
+    type: NodeType
+
+
 @dataclass
 class CustomLoss:
     type: NodeType
@@ -1755,5 +1761,5 @@ class NodeDataTypes:
                  CategoricalCrossentropy, CategoricalHinge, CosineSimilarity, Hinge, Huber, KLDivergence, LogCosh, 
                  MeanAbsoluteError, MeanAbsolutePercentageError, MeanSquaredError, MeanSquaredLogarithmicError, Poisson, 
                  SquaredHinge, Adadelta, Adagrad, Adam, Adamax, Ftrl, Nadam, RMSprop, SGD, OnnxErf, OnnxHardSigmoid, 
-                 OnnxReduceMean, OnnxSqrt, Dataset, RepresentationBlock, GroundTruth, CustomLoss, Visualizer, Lambda, 
-                 TFOpLambda, SlicingOpLambda, Repeat, Variable, Gather, FixedDropout]
+                 OnnxReduceMean, OnnxSqrt, Dataset, RepresentationBlock, GroundTruth, CustomLayer, CustomLoss, 
+                 Visualizer, Lambda, TFOpLambda, SlicingOpLambda, Repeat, Variable, Gather, FixedDropout]
